@@ -58,6 +58,8 @@ static GString *partial_input;
 static gulong text_change_handler;
 
 gboolean hide_entry(gpointer *user_data) {
+	(void)user_data;
+
 	timeout_id = 0;
 	gtk_widget_hide(entry_widget);
 	gtk_widget_grab_focus(draw);
@@ -66,7 +68,7 @@ gboolean hide_entry(gpointer *user_data) {
 	return FALSE;
 }
 
-static void show_entry() {
+static void show_entry(void) {
 	if (timeout_id) {
 		g_source_remove(timeout_id);
 		timeout_id = 0;
@@ -79,6 +81,11 @@ static void show_entry() {
 }
 
 static void clear_text(GtkAccelGroup *accel, GObject *window, guint keyval,  GdkModifierType modifier) {
+	(void)accel;
+	(void)window;
+	(void)keyval;
+	(void)modifier;
+
 	if( gtk_text_buffer_get_char_count(tb) ) {
 		gtk_text_buffer_set_text(tb,"",-1);
 		show_entry();
@@ -88,11 +95,16 @@ static void clear_text(GtkAccelGroup *accel, GObject *window, guint keyval,  Gdk
 }
 
 static void invert_text(GtkAccelGroup *accel, GObject *window, guint keyval,  GdkModifierType modifier) {
+	(void)accel;
+	(void)window;
+	(void)keyval;
+	(void)modifier;
+
 	inverted = !inverted;
 	gtk_widget_queue_draw(draw);
 }
 
-static char *get_text() {
+static char *get_text(void) {
 	GtkTextIter start, end;
 	gtk_text_buffer_get_start_iter(tb,&start);
 	gtk_text_buffer_get_end_iter(tb,&end);
@@ -101,8 +113,7 @@ static char *get_text() {
 
 
 static void redraw(GtkWidget *draw, cairo_t *cr, gpointer data) {
-	int q;
-
+	(void)data;
 	gdk_cairo_set_source_rgba(cr, inverted ? &black : &white);
 	cairo_paint(cr);
 
@@ -125,7 +136,7 @@ static void redraw(GtkWidget *draw, cairo_t *cr, gpointer data) {
 				pango_layout_set_alignment(layout,PANGO_ALIGN_RIGHT);
 				break;
 			default:
-				// we propably don't want to annoy the user, so default to
+				// we probably don't want to annoy the user, so default to
 				// the old default-behaviour:
 				pango_layout_set_alignment(layout,PANGO_ALIGN_CENTER);
 		}
@@ -154,7 +165,7 @@ static void redraw(GtkWidget *draw, cairo_t *cr, gpointer data) {
 			} else {
 				cairo_translate(cr, w2/2, h2/2);
 			}
-			cairo_rotate(cr, rotation * M_PI_2);
+			cairo_rotate(cr, rotation * G_PI_2);
 			cairo_scale(cr, s, s);
 			cairo_translate(cr, -w1/2, -h1/2);
 			gdk_cairo_set_source_rgba(cr, inverted ? &white : &black);
@@ -166,6 +177,9 @@ static void redraw(GtkWidget *draw, cairo_t *cr, gpointer data) {
 }
 
 static gboolean text_keypress(GtkWidget *widget, GdkEventButton *event, gpointer *user_data) {
+	(void)widget;
+	(void)user_data;
+
 	// forward signal to the text view
 	gboolean ret;
 	g_signal_emit_by_name(tv, "key-press-event", event, &ret);
@@ -174,6 +188,9 @@ static gboolean text_keypress(GtkWidget *widget, GdkEventButton *event, gpointer
 }
 
 static gboolean text_clicked(GtkWidget *widget, GdkEventButton *event, gpointer *user_data) {
+	(void)widget;
+	(void)user_data;
+
 	show_entry();
 	if (event->type == GDK_BUTTON_PRESS && event->button == 2) {
 		GtkClipboard *cb = gtk_clipboard_get(GDK_SELECTION_PRIMARY);
@@ -189,6 +206,9 @@ static gboolean text_clicked(GtkWidget *widget, GdkEventButton *event, gpointer
 }
 
 static gboolean read_chan(GIOChannel *chan, GIOCondition condition, gpointer data){
+	(void)condition;
+	(void)data;
+
 	gchar buf[1024];
 	GString *input;
 	GIOStatus stat = G_IO_STATUS_NORMAL;
@@ -227,7 +247,7 @@ static gboolean read_chan(GIOChannel *chan, GIOCondition condition, gpointer dat
 	}
 
 	// remove beginning and trailing newlines, if any
-	gssize cnt = 0;
+	gsize cnt = 0;
 	while ((input->len > cnt) && (input->str[cnt] == '\n')) {
 		cnt++;
 	}
@@ -249,15 +269,21 @@ static gboolean read_chan(GIOChannel *chan, GIOCondition condition, gpointer dat
 		return FALSE;
 }
 
-static void newtext() {
+static void newtext(void) {
 	gtk_widget_queue_draw(draw);
 }
 
-static void newtext_show_input() {
+static void newtext_show_input(void) {
 	show_entry();
 }
 
 static void move_cursor(GtkTextView* tv, GtkMovementStep step, gint count, gboolean extend_selection, gpointer user_data) {
+	(void)tv;
+	(void)step;
+	(void)count;
+	(void)extend_selection;
+	(void)user_data;
+
 	show_entry();
 }
 
@@ -278,11 +304,11 @@ static void usage(char *cmd) {
 	printf("Usage: %s [-h|--help] [-V|--version] [-f|--foreground=colordesc] [-b|--background=colordesc] [-i|--inverted] [-n|--font=fontdesc] [-r|--rotate=0,1,2,3] [-a|--align=0,1,2]\n", cmd);
 }
 
-static void version() {
+static void version(void) {
 	printf("%s\n", PACKAGE_STRING);
 }
 
-gboolean my_gdk_rgba_parse (GdkRGBA *rgba, const gchar *spec) {
+static void my_gdk_rgba_parse (GdkRGBA *rgba, const gchar *spec) {
 	gboolean ret = gdk_rgba_parse(rgba, spec);
 	if (!ret)  {
 	    fprintf (stderr, "Failed to parse color specification %s\n", spec);
